<!-- 我的工作 -->
<script setup lang="ts">
import type { VbenFormProps } from '@vben/common-ui';

import type { VxeGridProps } from '#/adapter/vxe-table';
import type { User } from '#/api/system/user/model';

import { ref } from 'vue';

import { useAccess } from '@vben/access';
import { Page, useVbenDrawer, useVbenModal } from '@vben/common-ui';
import { $t } from '@vben/locales';
import { preferences } from '@vben/preferences';
import { getVxePopupContainer } from '@vben/utils';

import {
  Avatar,
  Dropdown,
  Menu,
  MenuItem,
  Modal,
  Popconfirm,
  Space,
} from 'ant-design-vue';

import { useVbenVxeGrid, vxeCheckboxChecked } from '#/adapter/vxe-table';
import {
  userExport,
  userList,
  userRemove,
  userStatusChange,
} from '#/api/system/user';
import { TableSwitch } from '#/components/table';
import { commonDownloadExcel } from '#/utils/file/download';

import { columns, querySchema } from './data';
import userDrawer from './user-drawer.vue'; //工作详情
import userAssignWork from './user-assign-work.vue'; //工作下发
import userReport from './user-report.vue'; //工作汇报
import userImportModal from './user-import-modal.vue';
import userInfoModal from './user-info-modal.vue';
import userResetPwdModal from './user-reset-pwd-modal.vue';

/**
 * 导入
 */
const [UserImpotModal, userImportModalApi] = useVbenModal({
  connectedComponent: userImportModal,
});

function handleImport() {
  userImportModalApi.open();
}

// 左边部门用
const selectDeptId = ref<string[]>([]);

const formOptions: VbenFormProps = {
  schema: querySchema(),
  commonConfig: {
    labelWidth: 80,
    componentProps: {
      allowClear: true,
    },
  },
  wrapperClass: 'grid-cols-1 md:grid-cols-2 lg:grid-cols-3 xl:grid-cols-4',
  handleReset: async () => {
    selectDeptId.value = [];

    const { formApi, reload } = tableApi;
    await formApi.resetForm();
    const formValues = formApi.form.values;
    formApi.setLatestSubmissionValues(formValues);
    await reload(formValues);
  },
  // 日期选择格式化
  fieldMappingTime: [
    [
      'createTime',
      ['params[beginTime]', 'params[endTime]'],
      ['YYYY-MM-DD 00:00:00', 'YYYY-MM-DD 23:59:59'],
    ],
  ],
};

const gridOptions: VxeGridProps = {
  checkboxConfig: {
    // 高亮
    highlight: true,
    // 翻页时保留选中状态
    reserve: true,
    // 点击行选中
    trigger: 'default',
    checkMethod: ({ row }) => row?.userId !== 1,
  },
  columns,
  height: 'auto',
  keepSource: true,
  pagerConfig: {},
  proxyConfig: {
    ajax: {
      // 获取页面数据，搜索，重置也是
      /*
        @params page:页码参数
        @params formValues:表单参数
      */
      query: async ({ page }, formValues = {}) => {
        console.log("获取页面数据，")
        const res = {
          rows:[ {
            id:"0",  //工作id，编号
            workName:"工作名称1", //工作名称
            workClass:"工作类别", //工作类别
            workContent:"工作内容", //工作内容
            projectBudget:"项目预算", //项目预算
            amountProject:"项目金额", //项目金额
            responsibleDepartment:"负责部门", //负责部门
            Head:"负责人", //负责人
            Annual:"年度", //年度
            assessmentTime:"考核时间",//考核时间
            assessmentIndicators:"考核指标", //考核指标
            File:"文件地址", //文件上传
            taskStatus:"任务状态", //任务状态
            assignmentStatus:"分配状态", //分配状态
            workProgress:"工作进度" //工作进度
          } ],
          total:1
        }
        console.log( "res", res)
        return res
      },
    },
  },
  rowConfig: {
    keyField: 'userId',
    height: 48,
  },
  id: 'system-user-index',
};
const [BasicTable, tableApi] = useVbenVxeGrid({
  formOptions,
  gridOptions,
});
// 查看详情
const [UserDrawer, userDrawerApi] = useVbenDrawer({
  connectedComponent: userDrawer,
});
// 工作下发
const [userAssignWorkDrawer, userAssignWorkApi] = useVbenDrawer({
  connectedComponent: userAssignWork
})
// 工作汇报
const [userReportDrawer, userReportApi] = useVbenDrawer({
  connectedComponent: userReport
})
// 此方法暂未启用
function handleAdd() {
  userDrawerApi.setData({});
  userDrawerApi.open();
}
// 查看详情
function handleLook(row: any) {
  userDrawerApi.setData({ id: row.id, look: true });
  userDrawerApi.open();
}
// 工作下发
function handleAssigningWork(row: any) {
  userAssignWorkApi.setData({id:row.id, look:true})
  userAssignWorkApi.open()
}
// 工作汇报
function handleReport(row: any) {
  userReportApi.setData({ id: row.id, row: row });
  userReportApi.open();
}
function handleMultiDelete() {
  const rows = tableApi.grid.getCheckboxRecords();
  const ids = rows.map((row: User) => row.userId);
  Modal.confirm({
    title: '提示',
    okType: 'danger',
    content: `确认删除选中的${ids.length}条记录吗？`,
    onOk: async () => {
      await userRemove(ids);
      await tableApi.query();
    },
  });
}

function handleDownloadExcel() {
  commonDownloadExcel(userExport, '用户管理', tableApi.formApi.form.values, {
    fieldMappingTime: formOptions.fieldMappingTime,
  });
}

const [UserInfoModal, userInfoModalApi] = useVbenModal({
  connectedComponent: userInfoModal,
});
function handleUserInfo(row: User) {
  userInfoModalApi.setData({ userId: row.userId });
  userInfoModalApi.open();
}

const [UserResetPwdModal, userResetPwdModalApi] = useVbenModal({
  connectedComponent: userResetPwdModal,
});

function handleResetPwd(record: User) {
  userResetPwdModalApi.setData({ record });
  userResetPwdModalApi.open();
}

const { hasAccessByCodes } = useAccess();
</script>

<template>
  <Page :auto-content-height="true">
    <div class="flex h-full gap-[8px]">
      <BasicTable class="flex-1 overflow-hidden" table-title="工作列表">
        <template #toolbar-tools>
          <Space>
            <!-- 导出 -->
            <!-- <a-button
              @click="handleDownloadExcel"
            >
              {{ $t('pages.common.export') }}
            </a-button> -->
            <!-- 导入 -->
            <!-- <a-button
              v-access:code="['system:user:import']"
              @click="handleImport"
            >
              {{ $t('pages.common.import') }}
            </a-button> -->
            <!-- 删除 -->
            <a-button
              :disabled="!vxeCheckboxChecked(tableApi)"
              danger
              type="primary"
              @click="handleMultiDelete"
            >
              {{ $t('pages.common.delete') }}
            </a-button>
            <!-- 新增 -->
            <!-- <a-button
              type="primary"
              @click="handleAdd"
            >
              {{ $t('pages.common.WorkIssued') }}
            </a-button> -->
          </Space>
        </template>
        <template #avatar="{ row }">
          <!-- 可能要判断空字符串情况 所以没有使用?? -->
          <Avatar :src="row.avatar || preferences.app.defaultAvatar" />
        </template>
        <template #status="{ row }">
          <TableSwitch
            v-model="row.status"
            :api="() => userStatusChange(row)"
            :disabled="
              row.userId === 1 || !hasAccessByCodes(['system:user:edit'])
            "
            :reload="() => tableApi.query()"
          />
        </template>
        <template #action="{ row }">
            <Space>
              <!-- 查看 -->
              <ghost-button
                @click.stop="handleLook(row)"
              >
                {{ $t('pages.common.look') }}
              </ghost-button>
              <!-- 汇报 -->
              <ghost-button
                @click.stop="handleReport(row)"
              >
                {{ $t('pages.common.report') }}
              </ghost-button>
              <!-- 工作下发 -->
              <ghost-button
                @click.stop="handleAssigningWork(row)"
              >
                {{ $t('pages.common.AssigningWork') }}
              </ghost-button>
            </Space>
        </template>
      </BasicTable>
    </div>
    <UserImpotModal @reload="tableApi.query()" />
    <UserDrawer @reload="tableApi.query()" /> <!-- 工作详情 -->
    <userAssignWorkDrawer @reload="tableApi.query()" /> <!-- 工作下发 -->
    <userReportDrawer @reload="tableApi.query()" /> <!-- 工作汇报 -->
    <UserInfoModal />
    <UserResetPwdModal />
  </Page>
</template>
